import { CollectionData, CollectionRequest, CollectionRequestSort } from './interfaces/collection.interface';
import { BehaviorSubject, Observable } from 'rxjs';
import { CollectionProvider } from './providers/collection.provider';
import { FormControl } from '@angular/forms';
export declare const enum CollectionState {
    Initial = "initial",
    Error = "error",
    Empty = "empty",
    Data = "data"
}
export declare class Collection<T> {
    private readonly _provider;
    readonly _initialValues: Partial<CollectionRequest>;
    readonly queryControl: FormControl<string | null>;
    readonly queryFieldsControl: FormControl<string[]>;
    readonly pageNumberControl: FormControl<number>;
    readonly pageSizeControl: FormControl<number>;
    readonly sortControl: FormControl<CollectionRequestSort | CollectionRequestSort[]>;
    readonly data$: Observable<{
        response?: CollectionData<T>;
        request?: CollectionRequest;
        error?: Error;
        state: CollectionState;
        loading: boolean;
        initial: boolean;
    }>;
    readonly raw$: BehaviorSubject<CollectionData<T>>;
    readonly loading$: BehaviorSubject<boolean>;
    private _formatter;
    private _refresh$;
    private _requestCache;
    constructor(_provider: CollectionProvider<T>, _initialValues?: Partial<CollectionRequest>);
    refresh(): void;
    setFormatter(callback: (items: T[]) => T[] | Observable<T[]>): this;
    private getData;
    private formatResponse;
    private validateRequest;
    private getState;
    private cacheCollectionData;
    private get request();
    private getQueryObservable;
}
