import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy, ViewEncapsulation, HostBinding, Injector, Directive, Optional, Inject, HostListener, EventEmitter, booleanAttribute, forwardRef, TemplateRef, ContentChild, Input, Output } from '@angular/core';
import { Subscription, fromEvent, throttleTime, BehaviorSubject, isObservable } from 'rxjs';
import { trigger, transition, style, animate } from '@angular/animations';
import { AsyncPipe, NgTemplateOutlet } from '@angular/common';
import * as i3 from '@angular/cdk/a11y';
import { CdkTrapFocus } from '@angular/cdk/a11y';
import { ComponentPortal } from '@angular/cdk/portal';
import { WINDOW } from '@bravobit/bb-foundation';
import * as i1 from '@angular/cdk/overlay';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { map, shareReplay } from 'rxjs/operators';

const comboboxPanelAnimation = trigger('comboboxPanelAnimation', [
    transition(':enter', [
        style({ opacity: 0, transform: 'translateY(5px)' }),
        animate('300ms cubic-bezier(0, 0, .2, 1)', style({ opacity: 1, transform: 'none' }))
    ]),
    transition(':leave', [
        animate('300ms cubic-bezier(0, 0, .2, 1)', style({ opacity: 0, transform: 'translateY(5px)' }))
    ])
]);

class BbComboboxPanel {
    _combobox;
    _container;
    // Readonly data.
    items$;
    optionTemplate;
    // Host bindings.
    animation = true;
    constructor(_combobox, _container) {
        this._combobox = _combobox;
        this._container = _container;
        this.items$ = this._combobox.items$;
        this.optionTemplate = this._combobox?.optionTemplate ?? null;
    }
    select(item) {
        this._combobox.select(item?.value ?? null);
        this._container.close();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbComboboxPanel, deps: [{ token: BbCombobox }, { token: BbComboboxContainer }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.8", type: BbComboboxPanel, isStandalone: true, selector: "bb-combobox-panel", host: { attributes: { "role": "listbox" }, properties: { "@comboboxPanelAnimation": "this.animation" }, classAttribute: "bb-combobox-panel" }, hostDirectives: [{ directive: i3.CdkTrapFocus }], ngImport: i0, template: "@if (items$ | async; as items) {\n    @for (item of items; track $index) {\n        <div (click)=\"select(item)\"\n             tabindex=\"0\"\n             role=\"option\"\n             class=\"bb-combobox-panel-item\">\n            @if (optionTemplate) {\n                <ng-container *ngTemplateOutlet=\"optionTemplate; context: {item: item}\"></ng-container>\n            } @else {\n                {{ item?.label }}\n            }\n        </div>\n    }\n\n}\n", styles: [".bb-combobox-panel{width:100%;display:block;padding:.5rem;overflow-y:auto;overflow-x:hidden;border-radius:.5rem;background-color:#fff;box-shadow:#00000014 0 10px 40px 10px}.bb-combobox-panel-item{cursor:pointer;border-radius:.5rem;padding:.75rem 1.5rem}.bb-combobox-panel-item:hover,.bb-combobox-panel-item:focus{background-color:orange}.bb-combobox-panel-item:active{background-color:red}\n"], dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], animations: [comboboxPanelAnimation], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbComboboxPanel, decorators: [{
            type: Component,
            args: [{ selector: 'bb-combobox-panel', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, host: {
                        'class': 'bb-combobox-panel',
                        'role': 'listbox'
                    }, hostDirectives: [
                        { directive: CdkTrapFocus }
                    ], preserveWhitespaces: false, standalone: true, imports: [AsyncPipe, NgTemplateOutlet], animations: [comboboxPanelAnimation], template: "@if (items$ | async; as items) {\n    @for (item of items; track $index) {\n        <div (click)=\"select(item)\"\n             tabindex=\"0\"\n             role=\"option\"\n             class=\"bb-combobox-panel-item\">\n            @if (optionTemplate) {\n                <ng-container *ngTemplateOutlet=\"optionTemplate; context: {item: item}\"></ng-container>\n            } @else {\n                {{ item?.label }}\n            }\n        </div>\n    }\n\n}\n", styles: [".bb-combobox-panel{width:100%;display:block;padding:.5rem;overflow-y:auto;overflow-x:hidden;border-radius:.5rem;background-color:#fff;box-shadow:#00000014 0 10px 40px 10px}.bb-combobox-panel-item{cursor:pointer;border-radius:.5rem;padding:.75rem 1.5rem}.bb-combobox-panel-item:hover,.bb-combobox-panel-item:focus{background-color:orange}.bb-combobox-panel-item:active{background-color:red}\n"] }]
        }], ctorParameters: () => [{ type: BbCombobox }, { type: BbComboboxContainer }], propDecorators: { animation: [{
                type: HostBinding,
                args: ['@comboboxPanelAnimation']
            }] } });

class BbComboboxContainer {
    _overlay;
    _combobox;
    _viewContainerRef;
    _elementRef;
    _window;
    // State.
    _overlayRef = null;
    // Subscriptions.
    _subscription = new Subscription();
    constructor(_overlay, _combobox, _viewContainerRef, _elementRef, _window) {
        this._overlay = _overlay;
        this._combobox = _combobox;
        this._viewContainerRef = _viewContainerRef;
        this._elementRef = _elementRef;
        this._window = _window;
    }
    get width() {
        return this._elementRef?.nativeElement?.clientWidth ?? 0;
    }
    ngOnInit() {
        this.createOverlay();
        this.handleResizing();
        this.handleBackdropClick();
    }
    ngOnDestroy() {
        this._subscription?.unsubscribe();
        this._overlayRef?.dispose();
        this._overlayRef = null;
    }
    toggle() {
        if (!this._overlayRef) {
            return;
        }
        this._overlayRef?.hasAttached() ? this.close() : this.open();
    }
    open() {
        const injector = Injector.create({
            providers: [
                { provide: BbComboboxContainer, useValue: this },
                { provide: BbCombobox, useValue: this._combobox }
            ]
        });
        const component = new ComponentPortal(BbComboboxPanel, this._viewContainerRef, injector);
        this._overlayRef.attach(component);
    }
    close() {
        this._overlayRef?.detach();
    }
    getPositionStrategy() {
        const positions = this.getPositions();
        return this._overlay
            .position()
            .flexibleConnectedTo(this._elementRef)
            .withFlexibleDimensions(true)
            .withGrowAfterOpen(true)
            .withPush(false)
            .withViewportMargin(20)
            .withPositions(positions);
    }
    getPositions() {
        return [
            {
                originX: 'center',
                originY: 'bottom',
                overlayX: 'center',
                overlayY: 'top',
                offsetY: 10
            },
            {
                originX: 'center',
                originY: 'top',
                overlayX: 'center',
                overlayY: 'bottom',
                offsetY: -10
            }
        ];
    }
    resize() {
        this._overlayRef.updateSize({ width: this.width });
    }
    createOverlay() {
        const positionStrategy = this.getPositionStrategy();
        const scrollStrategy = this._overlay.scrollStrategies.reposition();
        this._overlayRef = this._overlay.create({
            positionStrategy,
            scrollStrategy,
            hasBackdrop: true,
            backdropClass: null,
            disposeOnNavigation: true,
            width: this.width
        });
    }
    handleBackdropClick() {
        if (!this._overlayRef) {
            return;
        }
        const subscription = this._overlayRef.backdropClick()
            .subscribe(() => this.close());
        this._subscription.add(subscription);
    }
    handleResizing() {
        if (!this._window) {
            return;
        }
        const resize$ = fromEvent(this._window, 'resize').pipe(throttleTime(20));
        const subscription = resize$.subscribe(() => this.resize());
        this._subscription.add(subscription);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbComboboxContainer, deps: [{ token: i1.Overlay }, { token: BbCombobox }, { token: i0.ViewContainerRef }, { token: i0.ElementRef }, { token: WINDOW, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.8", type: BbComboboxContainer, isStandalone: true, selector: "[bbComboboxContainer]", host: { listeners: { "click": "toggle()" } }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbComboboxContainer, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bbComboboxContainer]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1.Overlay }, { type: BbCombobox }, { type: i0.ViewContainerRef }, { type: i0.ElementRef }, { type: Window, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [WINDOW]
                }] }], propDecorators: { toggle: [{
                type: HostListener,
                args: ['click']
            }] } });

class BbComboboxOption {
    static ngTemplateContextGuard(directive, context) {
        return true;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbComboboxOption, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.8", type: BbComboboxOption, isStandalone: true, selector: "ng-template[bbComboboxOption]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbComboboxOption, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ng-template[bbComboboxOption]',
                    standalone: true
                }]
        }] });

class BbComboboxLabel {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbComboboxLabel, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.8", type: BbComboboxLabel, isStandalone: true, selector: "[bbComboboxLabel]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbComboboxLabel, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bbComboboxLabel]',
                    standalone: true
                }]
        }] });

class BbCombobox {
    // Children.
    labelComponent;
    optionTemplate;
    // Inputs.
    value = null;
    bindLabel = null;
    bindValue = null;
    disabled = false;
    set data(items) {
        this.handleData(items);
    }
    get data() {
        return this._cache$.getValue();
    }
    // Outputs.
    valueChange = new EventEmitter();
    // State.
    items$;
    // Methods.
    onChange = () => ({});
    onTouched = () => ({});
    // Cache.
    _cache$ = new BehaviorSubject([]);
    // Subscriptions.
    _dataSubscription = new Subscription();
    ngOnInit() {
        this.setItems();
    }
    ngOnDestroy() {
        this._dataSubscription?.unsubscribe();
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    writeValue(newValue) {
        this.value = newValue;
    }
    select(value) {
        this.value = value;
        this.emitChangeEvent();
    }
    setItems() {
        this.items$ = this._cache$.pipe(map(items => items.map(item => this.createComboboxItem(item))), shareReplay({ bufferSize: 1, refCount: true }));
    }
    createComboboxItem(data) {
        return {
            data,
            label: !!this.bindLabel ? (data?.[this.bindLabel] ?? null) : data,
            value: !!this.bindValue ? (data?.[this.bindValue] ?? null) : data
        };
    }
    setCache(items) {
        if (items === null || items === undefined) {
            return;
        }
        this._cache$.next(items);
    }
    handleData(items) {
        if (isObservable(items)) {
            return this.handleDataObservable(items);
        }
        return this.setCache(items);
    }
    handleDataObservable(items$) {
        this._dataSubscription?.unsubscribe();
        const subscription = items$.subscribe(items => this.setCache(items));
        this._dataSubscription.add(subscription);
    }
    emitChangeEvent() {
        this.onChange?.(this.value);
        this.valueChange.emit(this.value);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbCombobox, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "16.1.0", version: "18.2.8", type: BbCombobox, isStandalone: true, selector: "bb-combobox", inputs: { value: "value", bindLabel: "bindLabel", bindValue: "bindValue", disabled: ["disabled", "disabled", booleanAttribute], data: "data" }, outputs: { valueChange: "valueChange" }, host: { classAttribute: "bb-combobox" }, providers: [
            { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => BbCombobox), multi: true }
        ], queries: [{ propertyName: "labelComponent", first: true, predicate: BbComboboxLabel, descendants: true, read: TemplateRef }, { propertyName: "optionTemplate", first: true, predicate: BbComboboxOption, descendants: true, read: TemplateRef }], ngImport: i0, template: "<div bbComboboxContainer\n     class=\"bb-combobox-container\">\n    {{ value }}\n</div>\n", styles: [".bb-combobox{display:block}.bb-combobox-container{width:100%;height:2.5rem;display:block;padding:0 .75rem;line-height:2.5rem;border:1px solid black}\n"], dependencies: [{ kind: "directive", type: BbComboboxContainer, selector: "[bbComboboxContainer]" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbCombobox, decorators: [{
            type: Component,
            args: [{ selector: 'bb-combobox', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, host: { 'class': 'bb-combobox' }, preserveWhitespaces: false, providers: [
                        { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => BbCombobox), multi: true }
                    ], imports: [BbComboboxContainer], standalone: true, template: "<div bbComboboxContainer\n     class=\"bb-combobox-container\">\n    {{ value }}\n</div>\n", styles: [".bb-combobox{display:block}.bb-combobox-container{width:100%;height:2.5rem;display:block;padding:0 .75rem;line-height:2.5rem;border:1px solid black}\n"] }]
        }], propDecorators: { labelComponent: [{
                type: ContentChild,
                args: [BbComboboxLabel, { read: TemplateRef, static: false }]
            }], optionTemplate: [{
                type: ContentChild,
                args: [BbComboboxOption, { read: TemplateRef, static: false }]
            }], value: [{
                type: Input
            }], bindLabel: [{
                type: Input
            }], bindValue: [{
                type: Input
            }], disabled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], data: [{
                type: Input
            }], valueChange: [{
                type: Output
            }] } });

/**
 * Generated bundle index. Do not edit.
 */

export { BbCombobox, BbComboboxLabel, BbComboboxOption };
//# sourceMappingURL=bravobit-bb-foundation-combobox.mjs.map
