import * as i0 from '@angular/core';
import { InjectionToken, Component, ChangeDetectionStrategy, ViewEncapsulation, Input, ViewChild, HostBinding, createEnvironmentInjector, createComponent, Injectable, Optional, Inject, makeEnvironmentProviders, NgModule } from '@angular/core';
import * as i2 from '@bravobit/bb-foundation/localize';
import { BbLocalize } from '@bravobit/bb-foundation/localize';
import { NgTemplateOutlet, AsyncPipe } from '@angular/common';
import * as i1 from '@angular/cdk/platform';
import { trigger, transition, query, group, style, stagger, animate } from '@angular/animations';
import { BehaviorSubject } from 'rxjs';
import { share } from 'rxjs/operators';

var NotificationType;
(function (NotificationType) {
    NotificationType["Success"] = "success";
    NotificationType["Error"] = "error";
    NotificationType["Warning"] = "warning";
    NotificationType["Info"] = "info";
    NotificationType["Custom"] = "custom";
})(NotificationType || (NotificationType = {}));
class NotificationsConfig {
    mode;
    position;
    timeout;
    dismiss;
    localize;
    dismissText;
}
var NotificationsPosition;
(function (NotificationsPosition) {
    NotificationsPosition["TopRight"] = "flex-start|flex-end";
    NotificationsPosition["BottomRight"] = "flex-end|flex-end";
    NotificationsPosition["TopLeft"] = "flex-start|flex-start";
    NotificationsPosition["BottomLeft"] = "flex-end|flex-start";
})(NotificationsPosition || (NotificationsPosition = {}));
class NotificationsData {
    data;
    dismissText;
    position;
}
const NOTIFICATIONS_CONFIG = new InjectionToken('notifications config');

class BbNotificationsItem {
    _zone;
    _platform;
    _changeDetection;
    // Inputs.
    notification;
    dismissButtonText;
    // Elements.
    progressElementRef;
    // Data.
    _progress = 0;
    _count = 0;
    // Helper variables.
    _steps;
    _speed;
    _timer;
    _startTime;
    _difference;
    // Data.
    _radius = 19;
    _circumference = this._radius * 2 * Math.PI;
    get getClass() {
        return `bb-notifications-item ${this.notification.type}`;
    }
    constructor(_zone, _platform, _changeDetection) {
        this._zone = _zone;
        this._platform = _platform;
        this._changeDetection = _changeDetection;
    }
    get progressStrokeArray() {
        const value = Math.floor(this._circumference);
        return `${value}, ${value}`;
    }
    get progressStrokeOffset() {
        return Math.floor(this._circumference - this._progress / 100 * this._circumference);
    }
    get isContentString() {
        return typeof this.notification.content === 'string';
    }
    ngOnInit() {
        // Check if the notification timeout is not 0 and the platform is a browser.
        if (this.notification.timeout <= 0 || !this._platform.isBrowser) {
            this.notification.dismiss = true;
            return;
        }
        // Start the timeout.
        this.startTimeout();
    }
    ngOnDestroy() {
        // Clear the timeout if it was set.
        this._timer && window && window.clearTimeout && window.clearTimeout(this._timer);
    }
    callActionAndDestroy = (notification, action) => {
        // Perform the callback (if it exists).
        action && action.callback && action.callback();
        // Call the destroy method (if it exists).
        notification && notification.destroy && notification.destroy();
    };
    startTimeout() {
        // Calculate the steps of the timeout.
        this._steps = this.notification.timeout / 10;
        // Calculate the speed of the timeout.
        this._speed = this.notification.timeout / this._steps;
        // Get the start time.
        this._startTime = Date.now();
        // Set a new timer outside of Angular.
        this._zone.runOutsideAngular(() => this._timer = this.setTimeout(this.instance, this._speed));
    }
    instance = () => {
        // Calculate the difference.
        this._difference = (Date.now() - this._startTime) - (this._count * this._speed);
        // Add up the count.
        if (this._count++ === this._steps) {
            this.notification.destroy();
        }
        // Add the steps to the progress.
        this._progress += 100 / this._steps;
        // Set a new timer.
        this._timer = this.setTimeout(this.instance, this._speed - this._difference);
        // Run a new change detection cycle.
        this._zone.run(() => this._changeDetection.detectChanges());
    };
    setTimeout = (method, timeout) => {
        // Check if the window and method exist.
        if (!window || !window.setTimeout) {
            return null;
        }
        return window.setTimeout(method, timeout);
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbNotificationsItem, deps: [{ token: i0.NgZone }, { token: i1.Platform }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.8", type: BbNotificationsItem, isStandalone: true, selector: "bb-notifications-item", inputs: { notification: "notification", dismissButtonText: "dismissButtonText" }, host: { attributes: { "role": "alert" }, properties: { "class": "this.getClass" } }, viewQueries: [{ propertyName: "progressElementRef", first: true, predicate: ["progress"], descendants: true }], ngImport: i0, template: "<div class=\"notification-content-wrapper\">\n    <!--\n        The icon for the notification.\n\n        The icon is reflected by the type of the\n        notification. Same goes for the color and\n        background-color.\n    -->\n    <div [style.color]=\"notification?.color\"\n         [style.background-color]=\"notification?.backgroundColor\"\n         class=\"notification-icon-wrapper\">\n        <svg xmlns=\"http://www.w3.org/2000/svg\"\n             viewBox=\"0 0 16 19.5\"\n             class=\"notification-icon\">\n            <path\n                d=\"M8 19.5c1.1 0 2-.9 2-2H6c0 1.1.9 2 2 2zM14 13.5v-5c0-3.1-1.6-5.6-4.5-6.3v-.7C9.5.7 8.8 0 8 0S6.5.7 6.5 1.5v.7C3.6 2.9 2 5.4 2 8.5v5l-2 2v1h16v-1l-2-2z\">\n            </path>\n        </svg>\n\n        <!--\n            The circular progress for the notification.\n\n            The progress is only visible when a timeout is\n            set. The progress adapts to the time remaining\n            for the notification.\n        -->\n        @if (notification?.timeout > 0) {\n            <svg class=\"notification-progress-ring\"\n                 viewBox=\"0 0 40 40\"\n                 role=\"progressbar\">\n                <circle #progress\n                        [attr.stroke-dasharray]=\"progressStrokeArray\"\n                        [attr.stroke-dashoffset]=\"progressStrokeOffset\"\n                        [style.stroke]=\"notification?.color\"\n                        class=\"notification-progress-circle\"\n                        stroke-width=\"2\"\n                        fill=\"transparent\"\n                        r=\"19\"\n                        cx=\"20\"\n                        cy=\"20\">\n                </circle>\n            </svg>\n        }\n    </div>\n\n    <!--\n        The content for the notification.\n\n        This displays a string or a template based\n        on the given parameter by the user.\n    -->\n    <div class=\"notification-content\">\n        @if (isContentString) {\n            @switch (notification?.localize) {\n                @case (true) {\n                    {{ $any(notification?.content) | bbLocalize:{data: notification?.data} }}\n                }\n                @default {\n                    {{ notification?.content }}\n                }\n            }\n        } @else {\n            <ng-container *ngTemplateOutlet=\"$any(notification?.content)\"></ng-container>\n        }\n    </div>\n</div>\n\n<!--\n    The actions of the notification.\n\n    All actions are displayed here and are\n    based on the actions array the user provided.\n-->\n@if (notification?.actions?.length > 0 || notification?.dismiss) {\n    <div class=\"notification-actions\">\n        @for (action of notification?.actions; track $index) {\n            <button [class.destructive]=\"action?.type === 'cancel'\"\n                    (click)=\"callActionAndDestroy(notification, action)\"\n                    type=\"button\"\n                    class=\"notification-actions-button\">\n                <span class=\"notification-actions-button-highlight\">\n                    @if (notification?.localize) {\n                        {{ action?.title | bbLocalize:{data: notification?.data} }}\n                    } @else {\n                        {{ action?.title }}\n                    }\n                </span>\n            </button>\n        }\n        @if (notification?.dismiss) {\n            <button (click)=\"notification?.destroy()\"\n                    class=\"notification-actions-button destructive\"\n                    type=\"button\">\n                <span\n                    class=\"notification-actions-button-highlight\">{{ notification?.dismissText || dismissButtonText }}</span>\n            </button>\n        }\n    </div>\n}\n", styles: [".bb-notifications-item{display:flex;border-radius:.25rem;flex-direction:column;background-color:#fff;border:1px solid #d6dbe0}.bb-notifications-item.success .notification-icon-wrapper{color:#2dc05d;background-color:#ebfaf0}.bb-notifications-item.success .notification-progress-circle{stroke:#36d068}.bb-notifications-item.error .notification-icon-wrapper{color:#f43e3e;background-color:#feeeee}.bb-notifications-item.error .notification-progress-circle{stroke:#f55656}.bb-notifications-item.warning .notification-icon-wrapper{color:#f1ae00;background-color:#fff8e7}.bb-notifications-item.warning .notification-progress-circle{stroke:#ffbc0b}.bb-notifications-item.info .notification-icon-wrapper{color:#099bf6;background-color:#e9f6fe}.bb-notifications-item.info .notification-progress-circle{stroke:#22a5f7}.bb-notifications-item.custom .notification-icon-wrapper{color:#657385;background-color:#f3f5f6}.bb-notifications-item.custom .notification-progress-circle{stroke:#657385}.notification-content-wrapper{display:flex;padding:1.5rem;align-items:center}.notification-icon-wrapper{width:2.5rem;display:flex;height:2.5rem;-webkit-user-select:none;user-select:none;position:relative;border-radius:50%;align-items:center;justify-content:center;color:#657385;background-color:#f3f5f6}.notification-icon{width:100%;height:100%;padding:.75rem;fill:currentColor}.notification-content{flex:1;line-height:1.5;font-weight:500;font-size:.875rem;margin-left:1.5rem;color:#000000d9}.notification-content i{font-style:italic}.notification-content,.notification-actions-button{font-family:inherit}.notification-actions{display:flex;margin:0 1.5rem;-webkit-user-select:none;user-select:none;border-top:1px solid #f3f5f6}.notification-actions-button{flex:1;border:none;color:#22a5f7;cursor:pointer;font-weight:500;text-align:center;font-size:.875rem;padding:.75rem .125rem;background-color:transparent}.notification-actions-button:hover>.notification-actions-button-highlight,.notification-actions-button:focus>.notification-actions-button-highlight{background-color:#22a5f71a}.notification-actions-button:active>.notification-actions-button-highlight{background-color:#22a5f733}.notification-actions-button.destructive{color:#f55656}.notification-actions-button.destructive:hover>.notification-actions-button-highlight,.notification-actions-button.destructive:focus>.notification-actions-button-highlight{background-color:#f556561a}.notification-actions-button.destructive:active>.notification-actions-button-highlight{background-color:#f5565633}.notification-actions-button-highlight{display:inline-flex;border-radius:.75rem;padding:.25rem .75rem;transition:background-color .15s cubic-bezier(0,0,.2,1)}.notification-progress-ring{inset:0;width:100%;height:100%;position:absolute}.notification-progress-circle{transform:rotate(-90deg);transform-origin:50% 50%;stroke:#657385}\n"], dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "pipe", type: BbLocalize, name: "bbLocalize" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbNotificationsItem, decorators: [{
            type: Component,
            args: [{ selector: 'bb-notifications-item', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, host: { 'role': 'alert' }, preserveWhitespaces: false, standalone: true, imports: [NgTemplateOutlet, BbLocalize], template: "<div class=\"notification-content-wrapper\">\n    <!--\n        The icon for the notification.\n\n        The icon is reflected by the type of the\n        notification. Same goes for the color and\n        background-color.\n    -->\n    <div [style.color]=\"notification?.color\"\n         [style.background-color]=\"notification?.backgroundColor\"\n         class=\"notification-icon-wrapper\">\n        <svg xmlns=\"http://www.w3.org/2000/svg\"\n             viewBox=\"0 0 16 19.5\"\n             class=\"notification-icon\">\n            <path\n                d=\"M8 19.5c1.1 0 2-.9 2-2H6c0 1.1.9 2 2 2zM14 13.5v-5c0-3.1-1.6-5.6-4.5-6.3v-.7C9.5.7 8.8 0 8 0S6.5.7 6.5 1.5v.7C3.6 2.9 2 5.4 2 8.5v5l-2 2v1h16v-1l-2-2z\">\n            </path>\n        </svg>\n\n        <!--\n            The circular progress for the notification.\n\n            The progress is only visible when a timeout is\n            set. The progress adapts to the time remaining\n            for the notification.\n        -->\n        @if (notification?.timeout > 0) {\n            <svg class=\"notification-progress-ring\"\n                 viewBox=\"0 0 40 40\"\n                 role=\"progressbar\">\n                <circle #progress\n                        [attr.stroke-dasharray]=\"progressStrokeArray\"\n                        [attr.stroke-dashoffset]=\"progressStrokeOffset\"\n                        [style.stroke]=\"notification?.color\"\n                        class=\"notification-progress-circle\"\n                        stroke-width=\"2\"\n                        fill=\"transparent\"\n                        r=\"19\"\n                        cx=\"20\"\n                        cy=\"20\">\n                </circle>\n            </svg>\n        }\n    </div>\n\n    <!--\n        The content for the notification.\n\n        This displays a string or a template based\n        on the given parameter by the user.\n    -->\n    <div class=\"notification-content\">\n        @if (isContentString) {\n            @switch (notification?.localize) {\n                @case (true) {\n                    {{ $any(notification?.content) | bbLocalize:{data: notification?.data} }}\n                }\n                @default {\n                    {{ notification?.content }}\n                }\n            }\n        } @else {\n            <ng-container *ngTemplateOutlet=\"$any(notification?.content)\"></ng-container>\n        }\n    </div>\n</div>\n\n<!--\n    The actions of the notification.\n\n    All actions are displayed here and are\n    based on the actions array the user provided.\n-->\n@if (notification?.actions?.length > 0 || notification?.dismiss) {\n    <div class=\"notification-actions\">\n        @for (action of notification?.actions; track $index) {\n            <button [class.destructive]=\"action?.type === 'cancel'\"\n                    (click)=\"callActionAndDestroy(notification, action)\"\n                    type=\"button\"\n                    class=\"notification-actions-button\">\n                <span class=\"notification-actions-button-highlight\">\n                    @if (notification?.localize) {\n                        {{ action?.title | bbLocalize:{data: notification?.data} }}\n                    } @else {\n                        {{ action?.title }}\n                    }\n                </span>\n            </button>\n        }\n        @if (notification?.dismiss) {\n            <button (click)=\"notification?.destroy()\"\n                    class=\"notification-actions-button destructive\"\n                    type=\"button\">\n                <span\n                    class=\"notification-actions-button-highlight\">{{ notification?.dismissText || dismissButtonText }}</span>\n            </button>\n        }\n    </div>\n}\n", styles: [".bb-notifications-item{display:flex;border-radius:.25rem;flex-direction:column;background-color:#fff;border:1px solid #d6dbe0}.bb-notifications-item.success .notification-icon-wrapper{color:#2dc05d;background-color:#ebfaf0}.bb-notifications-item.success .notification-progress-circle{stroke:#36d068}.bb-notifications-item.error .notification-icon-wrapper{color:#f43e3e;background-color:#feeeee}.bb-notifications-item.error .notification-progress-circle{stroke:#f55656}.bb-notifications-item.warning .notification-icon-wrapper{color:#f1ae00;background-color:#fff8e7}.bb-notifications-item.warning .notification-progress-circle{stroke:#ffbc0b}.bb-notifications-item.info .notification-icon-wrapper{color:#099bf6;background-color:#e9f6fe}.bb-notifications-item.info .notification-progress-circle{stroke:#22a5f7}.bb-notifications-item.custom .notification-icon-wrapper{color:#657385;background-color:#f3f5f6}.bb-notifications-item.custom .notification-progress-circle{stroke:#657385}.notification-content-wrapper{display:flex;padding:1.5rem;align-items:center}.notification-icon-wrapper{width:2.5rem;display:flex;height:2.5rem;-webkit-user-select:none;user-select:none;position:relative;border-radius:50%;align-items:center;justify-content:center;color:#657385;background-color:#f3f5f6}.notification-icon{width:100%;height:100%;padding:.75rem;fill:currentColor}.notification-content{flex:1;line-height:1.5;font-weight:500;font-size:.875rem;margin-left:1.5rem;color:#000000d9}.notification-content i{font-style:italic}.notification-content,.notification-actions-button{font-family:inherit}.notification-actions{display:flex;margin:0 1.5rem;-webkit-user-select:none;user-select:none;border-top:1px solid #f3f5f6}.notification-actions-button{flex:1;border:none;color:#22a5f7;cursor:pointer;font-weight:500;text-align:center;font-size:.875rem;padding:.75rem .125rem;background-color:transparent}.notification-actions-button:hover>.notification-actions-button-highlight,.notification-actions-button:focus>.notification-actions-button-highlight{background-color:#22a5f71a}.notification-actions-button:active>.notification-actions-button-highlight{background-color:#22a5f733}.notification-actions-button.destructive{color:#f55656}.notification-actions-button.destructive:hover>.notification-actions-button-highlight,.notification-actions-button.destructive:focus>.notification-actions-button-highlight{background-color:#f556561a}.notification-actions-button.destructive:active>.notification-actions-button-highlight{background-color:#f5565633}.notification-actions-button-highlight{display:inline-flex;border-radius:.75rem;padding:.25rem .75rem;transition:background-color .15s cubic-bezier(0,0,.2,1)}.notification-progress-ring{inset:0;width:100%;height:100%;position:absolute}.notification-progress-circle{transform:rotate(-90deg);transform-origin:50% 50%;stroke:#657385}\n"] }]
        }], ctorParameters: () => [{ type: i0.NgZone }, { type: i1.Platform }, { type: i0.ChangeDetectorRef }], propDecorators: { notification: [{
                type: Input
            }], dismissButtonText: [{
                type: Input
            }], progressElementRef: [{
                type: ViewChild,
                args: ['progress']
            }], getClass: [{
                type: HostBinding,
                args: ['class']
            }] } });

const s = '250ms cubic-bezier(0, 0, .2, 1)';
const l = '400ms cubic-bezier(0, 0, .2, 1)';
const notificationAnimation = trigger('notificationListAnimation', [
    transition('* => *', [
        query(':enter', group([
            // 1. Set the initial state.
            style({ height: 0, opacity: 0, transform: 'translateX({{ to }}%) scale(0.95)' }),
            // 2. Start the animation to show the item.
            stagger(0, [
                animate(s, style({ height: '*' })),
                animate(l, style({ opacity: 1, transform: 'translateX(0) scale(0.95)' })),
                animate(s, style({ transform: 'translateX(0) scale(1)' }))
            ])
        ]), { optional: true }),
        query(':leave', group([
            // 1. Set the initial state.
            style({ height: '*', opacity: 1, transform: 'translateX(0) scale(1)' }),
            // 2. Start the animation to hide the item.
            stagger(0, [
                animate(s, style({ transform: 'translateX(0) scale(0.95)' })),
                animate(l, style({ opacity: 0, transform: 'translateX({{ to }}%) scale(0.95)' })),
                animate(s, style({ height: 0 }))
            ])
        ]), { optional: true })
    ])
]);

class BbNotificationsList {
    data;
    // Data.
    position = null;
    // Track by function.
    trackByFn = (_, item) => item?.id;
    constructor(data) {
        this.data = data;
    }
    get horizontalPosition() {
        return this.location.horizontal;
    }
    get verticalPosition() {
        return this.location.vertical;
    }
    get animation() {
        const to = this.horizontalPosition === 'flex-start'
            ? -50
            : 50;
        return { to };
    }
    get location() {
        const [y, x] = (this.data.position ?? '').split('|');
        return { vertical: y ?? null, horizontal: x ?? null };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbNotificationsList, deps: [{ token: NotificationsData }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.8", type: BbNotificationsList, isStandalone: true, selector: "bb-notifications-list", host: { attributes: { "role": "list" }, properties: { "style.justify-content": "this.horizontalPosition", "style.align-items": "this.verticalPosition" }, classAttribute: "bb-notifications-list" }, ngImport: i0, template: "<!--\n    The notifications list.\n\n    The list provides the animation effect for the\n    incoming notifications.\n-->\n@if (data?.data | async; as notifications) {\n    <div [@notificationListAnimation]=\"{value: notifications?.length, params: animation}\"\n         class=\"notifications-list-wrapper\">\n        <!--\n            The loop for the notifications.\n\n            All notifications will be displayed here. They\n            are wrapped within a wrapper which separates them.\n        -->\n        @for (notification of notifications; track notification?.id) {\n            <div class=\"notifications-item-wrapper\">\n                <bb-notifications-item [notification]=\"notification\"\n                                       [dismissButtonText]=\"data?.dismissText\">\n                </bb-notifications-item>\n            </div>\n        }\n    </div>\n}\n", styles: [".bb-notifications-list{inset:0;z-index:1100;display:flex;position:fixed;padding:.75rem;pointer-events:none}.notifications-list-wrapper{width:100%;display:block;max-width:25rem;position:relative}.notifications-item-wrapper{padding:0;margin:0 0 .75rem;pointer-events:all}\n"], dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "component", type: BbNotificationsItem, selector: "bb-notifications-item", inputs: ["notification", "dismissButtonText"] }], animations: [notificationAnimation], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbNotificationsList, decorators: [{
            type: Component,
            args: [{ selector: 'bb-notifications-list', animations: [notificationAnimation], changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, host: {
                        'class': 'bb-notifications-list',
                        'role': 'list'
                    }, preserveWhitespaces: false, standalone: true, imports: [AsyncPipe, BbNotificationsItem], template: "<!--\n    The notifications list.\n\n    The list provides the animation effect for the\n    incoming notifications.\n-->\n@if (data?.data | async; as notifications) {\n    <div [@notificationListAnimation]=\"{value: notifications?.length, params: animation}\"\n         class=\"notifications-list-wrapper\">\n        <!--\n            The loop for the notifications.\n\n            All notifications will be displayed here. They\n            are wrapped within a wrapper which separates them.\n        -->\n        @for (notification of notifications; track notification?.id) {\n            <div class=\"notifications-item-wrapper\">\n                <bb-notifications-item [notification]=\"notification\"\n                                       [dismissButtonText]=\"data?.dismissText\">\n                </bb-notifications-item>\n            </div>\n        }\n    </div>\n}\n", styles: [".bb-notifications-list{inset:0;z-index:1100;display:flex;position:fixed;padding:.75rem;pointer-events:none}.notifications-list-wrapper{width:100%;display:block;max-width:25rem;position:relative}.notifications-item-wrapper{padding:0;margin:0 0 .75rem;pointer-events:all}\n"] }]
        }], ctorParameters: () => [{ type: NotificationsData }], propDecorators: { horizontalPosition: [{
                type: HostBinding,
                args: ['style.justify-content']
            }], verticalPosition: [{
                type: HostBinding,
                args: ['style.align-items']
            }] } });

class Notifications {
    _platform;
    _applicationRef;
    _environmentInjector;
    _localize;
    _config;
    // Reference to the list.
    _ref;
    // The default settings for the notifications.
    _defaultMode;
    _defaultTimeout;
    _defaultLocalize;
    _defaultDismiss;
    _defaultDismissText;
    _defaultPosition;
    // The data containing the notifications.
    _notifications$ = new BehaviorSubject([]);
    constructor(_platform, _applicationRef, _environmentInjector, _localize, _config) {
        this._platform = _platform;
        this._applicationRef = _applicationRef;
        this._environmentInjector = _environmentInjector;
        this._localize = _localize;
        this._config = _config;
        // Get the config.
        const config = this._config ?? {};
        // Set the config.
        this._defaultMode = this.getProperty(config.mode, 'prepend');
        this._defaultTimeout = this.getProperty(config.timeout, 8000);
        this._defaultLocalize = this.getProperty(config.localize, false);
        this._defaultDismiss = this.getProperty(config.dismiss, true);
        this._defaultDismissText = this.getProperty(config.dismissText, 'Dismiss');
        this._defaultPosition = this.getProperty(config.position, NotificationsPosition.TopRight);
        // Create the element that holds all notifications.
        this.createElement();
    }
    success(content, actions = [], timeout = this._defaultTimeout) {
        return this.create({ content, timeout, actions, type: NotificationType.Success });
    }
    error(content, actions = [], timeout = this._defaultTimeout) {
        return this.create({ content, timeout, actions, type: NotificationType.Error });
    }
    warn(content, actions = [], timeout = this._defaultTimeout) {
        return this.create({ content, timeout, actions, type: NotificationType.Warning });
    }
    info(content, actions = [], timeout = this._defaultTimeout) {
        return this.create({ content, timeout, actions, type: NotificationType.Info });
    }
    create(notification) {
        // Compose a new notification item.
        const item = this.compose(notification);
        // Add the destroy function to the notification.
        item.destroy = () => this.pull(item);
        // Add the notification to the list
        // and return the item.
        return this.push(item);
    }
    push(notification) {
        // Get the current list.
        const oldList = this._notifications$.getValue();
        // Check which mode is activated.
        let newList;
        switch (this._defaultMode) {
            case 'append':
                newList = [...oldList, notification];
                break;
            case 'prepend':
            default:
                newList = [notification, ...oldList];
        }
        // Push the new notifications.
        this._notifications$.next(newList);
        // Return the notification for further use.
        return notification;
    }
    pull(notification) {
        // Get the current list.
        const newList = this._notifications$
            .getValue()
            .filter(item => item.id !== notification.id);
        // Push a new list.
        this._notifications$.next(newList);
    }
    compose(notification) {
        // Attach a random id to the notification.
        notification.id = Math.random().toString(36).substring(2, 12);
        // Set all properties.
        notification.type = this.getProperty(notification.type, NotificationType.Custom);
        notification.content = this.getProperty(notification.content, null);
        notification.data = this.getProperty(notification.data, {});
        notification.timeout = this.getProperty(notification.timeout, this._defaultTimeout);
        notification.localize = this.getProperty(notification.localize, this._defaultLocalize);
        notification.dismiss = this.getProperty(notification.dismiss, this._defaultDismiss);
        // Dismiss text localization.
        const dismissText = this.getProperty(notification.dismissText, this._defaultDismissText);
        notification.dismissText = this._defaultLocalize && this._localize
            ? this._localize.translate(dismissText)
            : dismissText;
        // Return the composed notification.
        return notification;
    }
    createElement() {
        const environmentInjector = createEnvironmentInjector([
            {
                provide: NotificationsData,
                useValue: {
                    data: this._notifications$.pipe(share()),
                    dismissText: this._defaultDismissText,
                    position: this._defaultPosition
                }
            }
        ], this._environmentInjector);
        // Create the component.
        this._ref = createComponent(BbNotificationsList, { environmentInjector });
        // Detect the changes.
        this._ref.changeDetectorRef.detectChanges();
        // Attach the component's view to the application
        // so that the change detection will run properly.
        this._applicationRef.attachView(this._ref.hostView);
        // If the platform is not a browser return.
        if (!this._platform.isBrowser) {
            return;
        }
        try {
            // Append the element to the DOM.
            document.body.appendChild(this._ref.location.nativeElement);
        }
        catch {
            // Don't do anything, because it must've failed.
        }
    }
    getProperty = (property, defaultValue) => {
        return typeof property === 'undefined'
            ? defaultValue
            : property;
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: Notifications, deps: [{ token: i1.Platform }, { token: i0.ApplicationRef }, { token: i0.EnvironmentInjector }, { token: i2.Localize, optional: true }, { token: NOTIFICATIONS_CONFIG, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: Notifications, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: Notifications, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1.Platform }, { type: i0.ApplicationRef }, { type: i0.EnvironmentInjector }, { type: i2.Localize, decorators: [{
                    type: Optional
                }] }, { type: NotificationsConfig, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [NOTIFICATIONS_CONFIG]
                }] }] });

function provideNotificationsConfig(config) {
    return makeEnvironmentProviders([
        { provide: NOTIFICATIONS_CONFIG, useValue: config ?? {} }
    ]);
}

class NotificationsModule {
    static forRoot(config) {
        return {
            ngModule: NotificationsModule,
            providers: [
                provideNotificationsConfig(config)
            ]
        };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: NotificationsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.8", ngImport: i0, type: NotificationsModule });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: NotificationsModule });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: NotificationsModule, decorators: [{
            type: NgModule
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { NOTIFICATIONS_CONFIG, NotificationType, Notifications, NotificationsConfig, NotificationsData, NotificationsModule, NotificationsPosition, provideNotificationsConfig };
//# sourceMappingURL=bravobit-bb-foundation-notifications.mjs.map
