import * as i0 from '@angular/core';
import { InjectionToken, inject, Component, ChangeDetectionStrategy, ViewEncapsulation, HostBinding, ViewContainerRef, ElementRef, Injector, booleanAttribute, Directive, Input, HostListener, NgModule } from '@angular/core';
import { BbTemplate } from '@bravobit/bb-foundation/utils';
import { Overlay } from '@angular/cdk/overlay';
import { ComponentPortal } from '@angular/cdk/portal';

const TOOLTIP_DATA = new InjectionToken('Data to display in tooltip');
const TOOLTIP_CLASS = new InjectionToken('Class to display in tooltip');

class TooltipContainerComponent {
    data = inject(TOOLTIP_DATA);
    classes = inject(TOOLTIP_CLASS);
    get classBinding() {
        return [this.classes]
            .filter(item => !!item)
            .join(' ');
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: TooltipContainerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.8", type: TooltipContainerComponent, isStandalone: true, selector: "bb-tooltip-container", host: { properties: { "class": "this.classBinding" }, classAttribute: "bb-tooltip-container" }, ngImport: i0, template: "<ng-template [bbTemplate]=\"data\">{{ data }}</ng-template>\n", styles: [".bb-tooltip-container{color:#fff;display:block;max-width:25rem;line-height:1.5;-webkit-user-select:none;user-select:none;position:relative;font-size:.875rem;pointer-events:none;border-radius:.5rem;padding:.5rem .75rem;background-color:#111}.bb-tooltip-container:after{width:0;height:0;content:\"\";display:block;position:absolute;border-style:solid}.bb-tooltip-container>small{display:block;font-size:.75rem;margin-top:.25rem;color:#fff6}.bb-tooltip-container-bottom,.bb-tooltip-container-top,.bb-tooltip-container-left,.bb-tooltip-container-right{pointer-events:none}.bb-tooltip-container-top .bb-tooltip-container:after{left:50%;top:100%;transform:translate(-50%);border-width:.5rem .5rem 0 .5rem;border-color:#111111 transparent transparent transparent}.bb-tooltip-container-bottom .bb-tooltip-container:after{left:50%;bottom:100%;transform:translate(-50%);border-width:0 .5rem .5rem .5rem;border-color:transparent transparent #111111 transparent}.bb-tooltip-container-left .bb-tooltip-container:after{top:50%;left:100%;transform:translateY(-50%);border-width:.5rem 0 .5rem .5rem;border-color:transparent transparent transparent #111111}.bb-tooltip-container-right .bb-tooltip-container:after{top:50%;right:100%;transform:translateY(-50%);border-width:.5rem .5rem .5rem 0;border-color:transparent #111111 transparent transparent}\n"], dependencies: [{ kind: "directive", type: BbTemplate, selector: "[bbTemplate]", inputs: ["bbTemplate"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: TooltipContainerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bb-tooltip-container', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, host: { 'class': 'bb-tooltip-container' }, preserveWhitespaces: false, standalone: true, imports: [BbTemplate], template: "<ng-template [bbTemplate]=\"data\">{{ data }}</ng-template>\n", styles: [".bb-tooltip-container{color:#fff;display:block;max-width:25rem;line-height:1.5;-webkit-user-select:none;user-select:none;position:relative;font-size:.875rem;pointer-events:none;border-radius:.5rem;padding:.5rem .75rem;background-color:#111}.bb-tooltip-container:after{width:0;height:0;content:\"\";display:block;position:absolute;border-style:solid}.bb-tooltip-container>small{display:block;font-size:.75rem;margin-top:.25rem;color:#fff6}.bb-tooltip-container-bottom,.bb-tooltip-container-top,.bb-tooltip-container-left,.bb-tooltip-container-right{pointer-events:none}.bb-tooltip-container-top .bb-tooltip-container:after{left:50%;top:100%;transform:translate(-50%);border-width:.5rem .5rem 0 .5rem;border-color:#111111 transparent transparent transparent}.bb-tooltip-container-bottom .bb-tooltip-container:after{left:50%;bottom:100%;transform:translate(-50%);border-width:0 .5rem .5rem .5rem;border-color:transparent transparent #111111 transparent}.bb-tooltip-container-left .bb-tooltip-container:after{top:50%;left:100%;transform:translateY(-50%);border-width:.5rem 0 .5rem .5rem;border-color:transparent transparent transparent #111111}.bb-tooltip-container-right .bb-tooltip-container:after{top:50%;right:100%;transform:translateY(-50%);border-width:.5rem .5rem .5rem 0;border-color:transparent #111111 transparent transparent}\n"] }]
        }], propDecorators: { classBinding: [{
                type: HostBinding,
                args: ['class']
            }] } });

class TooltipDirective {
    // Dependencies.
    _overlay = inject(Overlay);
    _viewContainer = inject(ViewContainerRef);
    _elementRef = inject((ElementRef));
    // Inputs.
    bbTooltip;
    bbTooltipClass = null;
    bbTooltipOrigin = null;
    bbTooltipPositions = [];
    bbTooltipDisabled = false;
    // State.
    _overlayRef = null;
    showTooltip() {
        if (this._overlayRef?.hasAttached() || this.bbTooltipDisabled) {
            return;
        }
        this.attachTooltip();
    }
    hideTooltip() {
        if (!this._overlayRef?.hasAttached()) {
            return;
        }
        this._overlayRef?.detach();
    }
    ngOnDestroy() {
        this._overlayRef?.dispose();
    }
    attachTooltip() {
        if (this._overlayRef === null) {
            const positionStrategy = this.getPositionStrategy();
            const scrollStrategy = this._overlay.scrollStrategies.reposition();
            this._overlayRef = this._overlay.create({ positionStrategy, scrollStrategy });
        }
        const injector = Injector.create({
            providers: [
                { provide: TOOLTIP_DATA, useValue: this.bbTooltip },
                { provide: TOOLTIP_CLASS, useValue: this.bbTooltipClass }
            ]
        });
        const component = new ComponentPortal(TooltipContainerComponent, this._viewContainer, injector);
        this._overlayRef.attach(component);
    }
    getPositionStrategy() {
        const element = this.bbTooltipOrigin ?? this._elementRef;
        const positions = this.getPositions();
        return this._overlay
            .position()
            .flexibleConnectedTo(element)
            .withPositions(positions);
    }
    getPositions() {
        if (this.bbTooltipPositions?.length > 0) {
            return this.bbTooltipPositions;
        }
        return [
            {
                originX: 'center',
                originY: 'top',
                overlayX: 'center',
                overlayY: 'bottom',
                offsetY: -10,
                panelClass: 'bb-tooltip-container-top'
            },
            {
                originX: 'center',
                originY: 'bottom',
                overlayX: 'center',
                overlayY: 'top',
                offsetY: 10,
                panelClass: 'bb-tooltip-container-bottom'
            },
            {
                originX: 'start',
                originY: 'center',
                overlayX: 'end',
                overlayY: 'center',
                offsetX: -10,
                panelClass: 'bb-tooltip-container-left'
            },
            {
                originX: 'end',
                originY: 'center',
                overlayX: 'start',
                overlayY: 'center',
                offsetX: 10,
                panelClass: 'bb-tooltip-container-right'
            }
        ];
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: TooltipDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "18.2.8", type: TooltipDirective, isStandalone: true, selector: "[bbTooltip]", inputs: { bbTooltip: "bbTooltip", bbTooltipClass: "bbTooltipClass", bbTooltipOrigin: "bbTooltipOrigin", bbTooltipPositions: "bbTooltipPositions", bbTooltipDisabled: ["bbTooltipDisabled", "bbTooltipDisabled", booleanAttribute] }, host: { listeners: { "mouseenter": "showTooltip()", "focus": "showTooltip()", "mouseleave": "hideTooltip()", "blur": "hideTooltip()" } }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: TooltipDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bbTooltip]',
                    standalone: true
                }]
        }], propDecorators: { bbTooltip: [{
                type: Input
            }], bbTooltipClass: [{
                type: Input
            }], bbTooltipOrigin: [{
                type: Input
            }], bbTooltipPositions: [{
                type: Input
            }], bbTooltipDisabled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], showTooltip: [{
                type: HostListener,
                args: ['mouseenter']
            }, {
                type: HostListener,
                args: ['focus']
            }], hideTooltip: [{
                type: HostListener,
                args: ['mouseleave']
            }, {
                type: HostListener,
                args: ['blur']
            }] } });

class TooltipModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: TooltipModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.8", ngImport: i0, type: TooltipModule, imports: [TooltipDirective], exports: [TooltipDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: TooltipModule });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: TooltipModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [TooltipDirective],
                    exports: [TooltipDirective]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { TOOLTIP_CLASS, TOOLTIP_DATA, TooltipContainerComponent, TooltipDirective, TooltipModule };
//# sourceMappingURL=bravobit-bb-foundation-tooltip.mjs.map
