import * as i0 from '@angular/core';
import { TemplateRef, Directive, Input, numberAttribute, HostBinding, HostListener, inject, NgModule } from '@angular/core';
import { GLOBAL_FOCUS_MODE } from '@bravobit/bb-foundation';
import * as i1 from '@angular/cdk/platform';

class BbTemplate {
    _templateRef;
    _viewContainerRef;
    set bbTemplate(content) {
        // Get the template.
        const template = content instanceof TemplateRef
            ? content
            : this._templateRef;
        // Clear the view container ref and create the view.
        this._viewContainerRef.clear();
        this._viewContainerRef.createEmbeddedView(template);
    }
    constructor(_templateRef, _viewContainerRef) {
        this._templateRef = _templateRef;
        this._viewContainerRef = _viewContainerRef;
    }
    // Required so that the template type checker can infer the type of the coerced inputs.
    static ngAcceptInputType_bbTemplate;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbTemplate, deps: [{ token: i0.TemplateRef }, { token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.8", type: BbTemplate, isStandalone: true, selector: "[bbTemplate]", inputs: { bbTemplate: "bbTemplate" }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbTemplate, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bbTemplate]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef }, { type: i0.ViewContainerRef }], propDecorators: { bbTemplate: [{
                type: Input
            }] } });

class BbAutosize {
    _renderer;
    _elementRef;
    // Min/max heights for the textarea.
    minHeight = null;
    maxHeight = null;
    rows = 1;
    constructor(_renderer, _elementRef) {
        this._renderer = _renderer;
        this._elementRef = _elementRef;
    }
    get element() {
        return this._elementRef?.nativeElement;
    }
    ngAfterViewInit() {
        // Update the styles after the DOM has loaded.
        this.updateStyles();
    }
    onWindowResize() {
        // Update the styles when the window is resized.
        this.updateStyles();
    }
    onInputReceived() {
        // Update the styles after the textarea received input.
        this.updateStyles();
    }
    updateStyles() {
        // Validate the element exists.
        if (!this.element) {
            return;
        }
        // Calculate border height which is not included in the scroll height.
        const borderHeight = this.element?.offsetHeight - this.element?.clientHeight;
        // Reset textarea height to auto that correctly calculate the new height.
        this.setHeight('auto');
        // Set new height.
        this.setHeight(`${this.element?.scrollHeight + borderHeight}px`);
    }
    setHeight(value) {
        this._renderer.setStyle(this.element, 'height', value);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbAutosize, deps: [{ token: i0.Renderer2 }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "18.2.8", type: BbAutosize, isStandalone: true, selector: "textarea[bbAutosize]", inputs: { minHeight: "minHeight", maxHeight: "maxHeight", rows: ["rows", "rows", numberAttribute] }, host: { listeners: { "window:resize": "onWindowResize()", "input": "onInputReceived()" }, properties: { "style.min-height": "this.minHeight", "style.max-height": "this.maxHeight", "rows": "this.rows" } }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbAutosize, decorators: [{
            type: Directive,
            args: [{
                    selector: 'textarea[bbAutosize]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.Renderer2 }, { type: i0.ElementRef }], propDecorators: { minHeight: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['style.min-height']
            }], maxHeight: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['style.max-height']
            }], rows: [{
                type: Input,
                args: [{ transform: numberAttribute }]
            }, {
                type: HostBinding,
                args: ['rows']
            }], onWindowResize: [{
                type: HostListener,
                args: ['window:resize']
            }], onInputReceived: [{
                type: HostListener,
                args: ['input']
            }] } });

class BbFocus {
    _zone;
    _platform;
    _elementRef;
    // Dependencies.
    _globalFocusMode = inject(GLOBAL_FOCUS_MODE);
    // Inputs.
    bbFocusMode = null;
    constructor(_zone, _platform, _elementRef) {
        this._zone = _zone;
        this._platform = _platform;
        this._elementRef = _elementRef;
    }
    get nativeElement() {
        return this._elementRef.nativeElement;
    }
    ngAfterViewInit() {
        // Run the method outside the Angular zone.
        this._zone.runOutsideAngular(() => this.focus());
    }
    isMobile() {
        return this._platform.IOS || this._platform.ANDROID;
    }
    focus() {
        const focusMode = this.bbFocusMode ?? this._globalFocusMode;
        if (focusMode === 'only-desktop' && this.isMobile()) {
            return;
        }
        // Check if set timeout exists and the user is
        // using the site on desktop devices.
        if (!setTimeout) {
            return;
        }
        // Check if the element and the focus method exist, if so focus the element.
        if (!this.nativeElement || !this.nativeElement.focus) {
            return;
        }
        // Execute the focus method in a timeout.
        setTimeout(() => this.nativeElement.focus(), 0);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbFocus, deps: [{ token: i0.NgZone }, { token: i1.Platform }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.8", type: BbFocus, isStandalone: true, selector: "[bbFocus]", inputs: { bbFocusMode: "bbFocusMode" }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbFocus, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bbFocus]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.NgZone }, { type: i1.Platform }, { type: i0.ElementRef }], propDecorators: { bbFocusMode: [{
                type: Input
            }] } });

class BbFocusTrap {
    _platform;
    _elementRef;
    _focusableElements = [
        'a[href]',
        'area[href]',
        'input:not([disabled]):not([type="hidden"]):not([aria-hidden])',
        'select:not([disabled]):not([aria-hidden])',
        'textarea:not([disabled]):not([aria-hidden])',
        'button:not([disabled]):not([aria-hidden])',
        'iframe',
        'object',
        'embed',
        '[contenteditable]',
        '[tabindex]:not([tabindex^="-"])'
    ];
    constructor(_platform, _elementRef) {
        this._platform = _platform;
        this._elementRef = _elementRef;
    }
    onKeydown(event) {
        // Validate it is a tab event.
        if (!this.isTabEvent(event)) {
            return;
        }
        // Trap the focus inside the element.
        return this.trapFocus(event);
    }
    trapFocus(event) {
        // Validate that the DOM is available.
        if (!this._platform.isBrowser) {
            return;
        }
        // Get all focusable nodes.
        const focusableNodes = this.getFocusableNodes();
        // Focus the first available element if the focus
        // is not in the modal.
        if (!this.element.contains(document.activeElement)) {
            return this.focus(focusableNodes[0]);
        }
        const focusedItemIndex = focusableNodes.indexOf(document.activeElement);
        if (event.shiftKey && focusedItemIndex === 0) {
            this.focus(focusableNodes[focusableNodes.length - 1]);
            return event.preventDefault();
        }
        if (!event.shiftKey && focusedItemIndex === focusableNodes.length - 1) {
            this.focus(focusableNodes[0]);
            return event.preventDefault();
        }
    }
    get element() {
        return this._elementRef.nativeElement;
    }
    getFocusableNodes() {
        const nodes = this.element.querySelectorAll(this._focusableElements);
        return Array(...nodes);
    }
    focus = (element) => {
        return element && element.focus && element.focus();
    };
    isTabEvent = (event) => {
        return event?.key === 'Tab' || event?.keyCode === 9;
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbFocusTrap, deps: [{ token: i1.Platform }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.8", type: BbFocusTrap, isStandalone: true, selector: "[bbFocusTrap]", host: { listeners: { "keydown": "onKeydown($event)" } }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: BbFocusTrap, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bbFocusTrap]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1.Platform }, { type: i0.ElementRef }], propDecorators: { onKeydown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }] } });

class UtilsModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: UtilsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.8", ngImport: i0, type: UtilsModule, imports: [BbTemplate,
            BbAutosize,
            BbFocus,
            BbFocusTrap], exports: [BbTemplate,
            BbAutosize,
            BbFocus,
            BbFocusTrap] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: UtilsModule });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.8", ngImport: i0, type: UtilsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        BbTemplate,
                        BbAutosize,
                        BbFocus,
                        BbFocusTrap
                    ],
                    exports: [
                        BbTemplate,
                        BbAutosize,
                        BbFocus,
                        BbFocusTrap
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BbAutosize, BbFocus, BbFocusTrap, BbTemplate, UtilsModule };
//# sourceMappingURL=bravobit-bb-foundation-utils.mjs.map
